@@ -2,6 +2,7 @@ __all__ = [
     "CrossAccountCheckingRule",
     "CrossAccountTrustRule",
     "ElasticsearchDomainCrossAccountTrustRule",
+    "GenericCrossAccountTrustRule",
     "KMSKeyCrossAccountTrustRule",
     "OpenSearchDomainCrossAccountTrustRule",
     "S3CrossAccountTrustRule",
@@ -53,7 +54,7 @@ class CrossAccountCheckingRule(PrincipalCheckingRule, ABC):
                 properties = resource.Properties
                 policy_document = getattr(properties, self.PROPERTY_WITH_POLICYDOCUMENT)
                 if policy_document:
-                    for statement in policy_document._statement_as_list():
+                    for statement in policy_document.statement_as_list():
                         filters_available_context = {
                             "config": self._config,
                             "extras": extras,
@@ -105,6 +106,52 @@ class CrossAccountCheckingRule(PrincipalCheckingRule, ABC):
                         )
 
 
+class GenericCrossAccountTrustRule(CrossAccountCheckingRule):
+    """
+    Checks if the trust policy of every resource grants permissions to principals from other accounts.
+    Do not use whole accounts as principals.
+    It doesn't check if policies allow permissions to assume roles in other accounts.
+
+    Risk:
+        It might allow other AWS identities to escalate privileges.
+
+    Fix:
+        If cross account permissions are required, the stack should be added to the allowlist for this rule.
+        Otherwise, the access should be removed from the CloudFormation definition.
+
+    Filters context:
+        | Parameter   | Type        | Description                                                    |
+        |:-----------:|:-----------:|:--------------------------------------------------------------:|
+        |`config`     | `str`       | `config` variable available inside the rule                    |
+        |`extras`     | `str`       | `extras` variable available inside the rule                    |
+        |`logical_id` | `str`       | ID used in CloudFormation to refer the resource being analysed |
+        |`resource`   | `Generic`   | Resource that is being addressed                               |
+        |`statement`  | `Statement` | Statement being checked found in the Resource                  |
+        |`principal`  | `str`       | AWS Principal being checked found in the statement             |
+        |`account_id` | `str`       | Account ID found in the principal                              |
+    """
+
+    REASON = "{} has forbidden cross-account with {}"
+
+    def invoke(self, cfmodel: CFModel, extras: Optional[Dict] = None) -> Result:
+        result = Result()
+        for logical_id, resource in cfmodel.Resources.items():
+            policy_documents = resource.policy_documents
+            if policy_documents:
+                for document in policy_documents:
+                    for statement in document.policy_document.statement_as_list():
+                        filters_available_context = {
+                            "config": self._config,
+                            "extras": extras,
+                            "logical_id": logical_id,
+                            "resource": resource,
+                            "statement": statement,
+                        }
+                        self._do_statement_check(result, logical_id, statement, filters_available_context)
+
+        return result
+
+
 class CrossAccountTrustRule(CrossAccountCheckingRule):
     """
     Checks if the trust policy of a role grants permissions to principals from other accounts.
@@ -120,9 +167,9 @@ class CrossAccountTrustRule(CrossAccountCheckingRule):
     Filters context:
         | Parameter   | Type        | Description                                                    |
         |:-----------:|:-----------:|:--------------------------------------------------------------:|
-        |`config`     | str         | `config` variable available inside the rule                    |
-        |`extras`     | str         | `extras` variable available inside the rule                    |
-        |`logical_id` | str         | ID used in Cloudformation to refer the resource being analysed |
+        |`config`     | `str`       | `config` variable available inside the rule                    |
+        |`extras`     | `str`       | `extras` variable available inside the rule                    |
+        |`logical_id` | `str`       | ID used in CloudFormation to refer the resource being analysed |
         |`resource`   | `IAMRole`   | Resource that is being addressed                               |
         |`statement`  | `Statement` | Statement being checked found in the Resource                  |
         |`principal`  | `str`       | AWS Principal being checked found in the statement             |
@@ -136,6 +183,8 @@ class CrossAccountTrustRule(CrossAccountCheckingRule):
 
 class S3CrossAccountTrustRule(CrossAccountCheckingRule):
     """
+    To be replaced by GenericCrossAccountTrustRule.
+
     Check for cross account access in S3 bucket policies. Cross account access by default should not be allowed.
 
     Risk:
@@ -148,9 +197,9 @@ class S3CrossAccountTrustRule(CrossAccountCheckingRule):
     Filters context:
         | Parameter   | Type             | Description                                                    |
         |:-----------:|:----------------:|:--------------------------------------------------------------:|
-        |`config`     | str              | `config` variable available inside the rule                    |
-        |`extras`     | str              | `extras` variable available inside the rule                    |
-        |`logical_id` | str              | ID used in Cloudformation to refer the resource being analysed |
+        |`config`     | `str`            | `config` variable available inside the rule                    |
+        |`extras`     | `str`            | `extras` variable available inside the rule                    |
+        |`logical_id` | `str`            | ID used in CloudFormation to refer the resource being analysed |
         |`resource`   | `S3BucketPolicy` | Resource that is being addressed                               |
         |`statement`  | `Statement`      | Statement being checked found in the Resource                  |
         |`principal`  | `str`            | AWS Principal being checked found in the statement             |
@@ -164,6 +213,8 @@ class S3CrossAccountTrustRule(CrossAccountCheckingRule):
 
 class KMSKeyCrossAccountTrustRule(CrossAccountCheckingRule):
     """
+    To be replaced by GenericCrossAccountTrustRule.
+
     Checks for KMS keys that allow cross-account principals to get access to the key.
 
     Risk:
@@ -176,9 +227,9 @@ class KMSKeyCrossAccountTrustRule(CrossAccountCheckingRule):
     Filters context:
         | Parameter   | Type        | Description                                                    |
         |:-----------:|:-----------:|:--------------------------------------------------------------:|
-        |`config`     | str         | `config` variable available inside the rule                    |
-        |`extras`     | str         | `extras` variable available inside the rule                    |
-        |`logical_id` | str         | ID used in Cloudformation to refer the resource being analysed |
+        |`config`     | `str`       | `config` variable available inside the rule                    |
+        |`extras`     | `str`       | `extras` variable available inside the rule                    |
+        |`logical_id` | `str`       | ID used in CloudFormation to refer the resource being analysed |
         |`resource`   | `KMSKey`    | Resource that is being addressed                               |
         |`statement`  | `Statement` | Statement being checked found in the Resource                  |
         |`principal`  | `str`       | AWS Principal being checked found in the statement             |
@@ -192,6 +243,8 @@ class KMSKeyCrossAccountTrustRule(CrossAccountCheckingRule):
 
 class ElasticsearchDomainCrossAccountTrustRule(CrossAccountCheckingRule):
     """
+    To be replaced by GenericCrossAccountTrustRule.
+
     Checks for Elasticsearch domains that allow cross-account principals to get access.
 
     Risk:
@@ -204,9 +257,9 @@ class ElasticsearchDomainCrossAccountTrustRule(CrossAccountCheckingRule):
     Filters context:
         | Parameter   | Type        | Description                                                    |
         |:-----------:|:-----------:|:--------------------------------------------------------------:|
-        |`config`     | str         | `config` variable available inside the rule                    |
-        |`extras`     | str         | `extras` variable available inside the rule                    |
-        |`logical_id` | str         | ID used in Cloudformation to refer the resource being analysed |
+        |`config`     | `str`       | `config` variable available inside the rule                    |
+        |`extras`     | `str`       | `extras` variable available inside the rule                    |
+        |`logical_id` | `str`       | ID used in CloudFormation to refer the resource being analysed |
         |`resource`   | `ESDomain`  | Resource that is being addressed                               |
         |`statement`  | `Statement` | Statement being checked found in the Resource                  |
         |`principal`  | `str`       | AWS Principal being checked found in the statement             |
@@ -220,6 +273,8 @@ class ElasticsearchDomainCrossAccountTrustRule(CrossAccountCheckingRule):
 
 class OpenSearchDomainCrossAccountTrustRule(CrossAccountCheckingRule):
     """
+    To be replaced by GenericCrossAccountTrustRule.
+
     Checks for OpenSearch domains that allow cross-account principals to get access.
 
     Risk:
@@ -232,9 +287,9 @@ class OpenSearchDomainCrossAccountTrustRule(CrossAccountCheckingRule):
     Filters context:
         | Parameter   | Type               | Description                                                    |
         |:-----------:|:------------------:|:--------------------------------------------------------------:|
-        |`config`     | str                | `config` variable available inside the rule                    |
-        |`extras`     | str                | `extras` variable available inside the rule                    |
-        |`logical_id` | str                | ID used in Cloudformation to refer the resource being analysed |
+        |`config`     | `str`              | `config` variable available inside the rule                    |
+        |`extras`     | `str`              | `extras` variable available inside the rule                    |
+        |`logical_id` | `str`              | ID used in CloudFormation to refer the resource being analysed |
         |`resource`   | `OpenSearchDomain` | Resource that is being addressed                               |
         |`statement`  | `Statement`        | Statement being checked found in the Resource                  |
         |`principal`  | `str`              | AWS Principal being checked found in the statement             |
